#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>

struct Point 
{ 
   double x, y;

   Point() {}
   Point(double nx, double ny): x(nx), y(ny) {}
   Point(const Point &p): x(p.x), y(p.y) {}

   Point operator + (Point b) { return Point(x + b.x, y + b.y); }
   Point operator - (Point b) { return Point(x - b.x, y - b.y); }
   Point operator * (double k) { return Point(k * x, k * y); }
   bool operator != (Point b) { return x != b.x || y != b.y; }
};

double Length(Point a) 
{ 
   return sqrt(a.x * a.x + a.y * a.y); 
}

int compare( const void *arg1, const void *arg2 )
{
        if( *(double*)arg1 < *(double*)arg2 ) return -1;
   else if( *(double*)arg1 > *(double*)arg2 ) return  1;
   else return 0;
}

const int MAXSTONES = 210;

int nstones;
Point stones[MAXSTONES];
double range[MAXSTONES][MAXSTONES];
bool visited[MAXSTONES];

int nsranges;
double sranges[MAXSTONES * MAXSTONES];

double FrogDist()
{
   int n, i, j;

   for ( i = 0; i < nstones; i++ ) visited[i] = false;
   visited[0] = true;

   for ( n = 0; n < nsranges; n++ ) {
      int newv;
      double cr = sranges[n];

      do {
         newv = 0;
         for ( i = 0; i < nstones; i++ ) if ( visited[i] ) {
            for ( j = 0; j < nstones; j++ )
               if ( !visited[j] && range[i][j] < cr + 1e-6 ) {
                  visited[j] = true;
                  newv++;
               }
         }
         if ( visited[1] ) return cr;
      } while ( newv > 0 );
   }

   return -1;     // shouldn't be here
}

int main()
{
   int scenario=1;

   while ( 1 ) {
      scanf( " %d" , &nstones );
      if( nstones==0 ) break;

      for ( int s = 0; s < nstones; s++ ) {
         int x, y;
         scanf(" %d %d", &x, &y);
         stones[s] = Point(x, y);
      }

      nsranges=0;
      for ( int a = 0; a < nstones; a++ )
         for ( int b = a + 1; b < nstones; b++ ) {
            double r = Length(stones[a] - stones[b]);
            range[a][b]=range[b][a]=r;
            sranges[ nsranges++ ]=r;
         }
      qsort( sranges , nsranges , sizeof(double) , compare );

      printf("Scenario #%d\n",scenario++);
      printf("Frog Distance = %.3f\n\n", FrogDist());
   }

   return 0;
}